@@ -63,6 +63,7 @@ import files_sdk.models.message_comment_reaction as message_comment_reaction
 import files_sdk.models.message_reaction as message_reaction
 import files_sdk.models.notification as notification
 import files_sdk.models.outbound_connection_log as outbound_connection_log
+import files_sdk.models.partner as partner
 import files_sdk.models.payment as payment
 import files_sdk.models.payment_line_item as payment_line_item
 import files_sdk.models.permission as permission
@@ -78,6 +79,7 @@ import files_sdk.models.remote_server as remote_server
 import files_sdk.models.remote_server_configuration_file as remote_server_configuration_file
 import files_sdk.models.request as request
 import files_sdk.models.restore as restore
+import files_sdk.models.scim_log as scim_log
 import files_sdk.models.session as session
 import files_sdk.models.settings_change as settings_change
 import files_sdk.models.sftp_action_log as sftp_action_log
@@ -174,6 +176,7 @@ from files_sdk.models.message_comment_reaction import MessageCommentReaction
 from files_sdk.models.message_reaction import MessageReaction
 from files_sdk.models.notification import Notification
 from files_sdk.models.outbound_connection_log import OutboundConnectionLog
+from files_sdk.models.partner import Partner
 from files_sdk.models.payment import Payment
 from files_sdk.models.payment_line_item import PaymentLineItem
 from files_sdk.models.permission import Permission
@@ -191,6 +194,7 @@ from files_sdk.models.remote_server_configuration_file import (
 )
 from files_sdk.models.request import Request
 from files_sdk.models.restore import Restore
+from files_sdk.models.scim_log import ScimLog
 from files_sdk.models.session import Session
 from files_sdk.models.settings_change import SettingsChange
 from files_sdk.models.sftp_action_log import SftpActionLog
@@ -227,7 +231,7 @@ session_id = None
 source_ip = None
 base_url = "https://app.files.com"
 base_path = "api/rest/v1"
-version = "1.6.61"
+version = "1.6.92"
 
 __version__ = version
 
